﻿// Searcher
// (c) 2020 Steve Banham

scriptName = "Searcher";
scriptVersion = "1.0";
scriptDate = "26/4/2020";
scriptCopyright = "(c) 2020 Steve Banham";
scriptMinVersion = "12.20";
scriptDesc = "Find selected filename, or clipboard content in various search engines.";

function OnInit(initData) {
    initData.name = scriptName;
    initData.version = scriptVersion;
    initData.copyright = scriptCopyright;
    initData.desc = scriptDesc;
    initData.default_enable = true;
    initData.min_version = scriptMinVersion;

    var cmd = initData.AddCommand();
    cmd.name = "Searcher";
    cmd.method = "onSearcher";
    cmd.desc = "Find selected filename, or clipboard content in various search engines.";
    cmd.label = "Searcher";
    cmd.template = "CLIP/S";
}

function onSearcher(scriptCmdData) {

    srcTab = scriptCmdData.func.sourcetab;

    var dlg = DOpus.Dlg;
    dlg.title = scriptName + " " + scriptVersion+ " - Directory Opus";
    dlg.template = "dlgSearch";
	dlg.LoadPosition("Steve_Searcher");
    dlg.detach = true;
    dlg.Show();

    dlg.Control("listEngines").columns.AddColumn("Search Engine");
    dlg.Control("listEngines").columns.AddColumn("Active");

    dlg.Control("listEngines").AddItem("Google");                           // 0
    dlg.Control("listEngines").AddItem("Google Images");                    // 1
    dlg.Control("listEngines").AddItem("Bing");                             // 2
    dlg.Control("listEngines").AddItem("Bing Images");                      // 3
    dlg.Control("listEngines").AddItem("DuckDuckGo");                       // 4
    dlg.Control("listEngines").AddItem("DuckDuckGo Images");                // 5
    dlg.Control("listEngines").AddItem("Wikipedia");                        // 6
    dlg.Control("listEngines").AddItem("Opus Resource Centre\t\t\t\t\t");   // 7

    if (!DOpus.Vars.Exists("Searcher_Google") || DOpus.Vars.Get("Searcher_Google") == undefined){
        DOpus.Vars.Set("Searcher_Google") = "Yes";
        dlg.Control("listEngines").GetItemAt(0).subitems(0) = "Yes";
    }
    else dlg.Control("listEngines").GetItemAt(0).subitems(0) = DOpus.Vars.Get("Searcher_Google");

    if (!DOpus.Vars.Exists("Searcher_Google_Images") || DOpus.Vars.Get("Searcher_Google_Images") == undefined){
        DOpus.Vars.Set("Searcher_Google_Images") = "Yes";
        dlg.Control("listEngines").GetItemAt(1).subitems(0) = "Yes";
    }
    else dlg.Control("listEngines").GetItemAt(1).subitems(0) = DOpus.Vars.Get("Searcher_Google_Images");

    if (!DOpus.Vars.Exists("Searcher_Bing") || DOpus.Vars.Get("Searcher_Bing") == undefined){
        DOpus.Vars.Set("Searcher_Bing") = "Yes";
        dlg.Control("listEngines").GetItemAt(2).subitems(0) = "Yes";
    }
    else dlg.Control("listEngines").GetItemAt(2).subitems(0) = DOpus.Vars.Get("Searcher_Bing");

    if (!DOpus.Vars.Exists("Searcher_Bing_Images") || DOpus.Vars.Get("Searcher_Bing_Images") == undefined){
        DOpus.Vars.Set("Searcher_Bing_Images") = "Yes";
        dlg.Control("listEngines").GetItemAt(3).subitems(0) = "Yes";
    }
    else dlg.Control("listEngines").GetItemAt(3).subitems(0) = DOpus.Vars.Get("Searcher_Bing_Images");

    if (!DOpus.Vars.Exists("Searcher_Duck") || DOpus.Vars.Get("Searcher_Duck") == undefined){
        DOpus.Vars.Set("Searcher_Duck") = "Yes";
        dlg.Control("listEngines").GetItemAt(4).subitems(0) = "Yes";
    }
    else dlg.Control("listEngines").GetItemAt(4).subitems(0) = DOpus.Vars.Get("Searcher_Duck");

    if (!DOpus.Vars.Exists("Searcher_Duck_Images") || DOpus.Vars.Get("Searcher_Duck_Images") == undefined){
        DOpus.Vars.Set("Searcher_Duck_Images") = "Yes";
        dlg.Control("listEngines").GetItemAt(5).subitems(0) = "Yes";
    }
    else dlg.Control("listEngines").GetItemAt(5).subitems(0) = DOpus.Vars.Get("Searcher_Duck_Images");

    if (!DOpus.Vars.Exists("Searcher_Wikipedia") || DOpus.Vars.Get("Searcher_Wikipedia") == undefined){
        DOpus.Vars.Set("Searcher_Wikipedia") = "Yes";
        dlg.Control("listEngines").GetItemAt(6).subitems(0) = "Yes";
    }
    else dlg.Control("listEngines").GetItemAt(6).subitems(0) = DOpus.Vars.Get("Searcher_Wikipedia");

    if (!DOpus.Vars.Exists("Searcher_Opus") || DOpus.Vars.Get("Searcher_Opus") == undefined){
        DOpus.Vars.Set("Searcher_Opus") = "Yes";
        dlg.Control("listEngines").GetItemAt(7).subitems(0) = "Yes";
    }
    else dlg.Control("listEngines").GetItemAt(7).subitems(0) = DOpus.Vars.Get("Searcher_Opus");

    if (scriptCmdData.func.args.got_arg.clip) {
        dlg.Control("editSearch").value = DOpus.GetClip();
    }
    else {
        if (srcTab.stats.selitems > 0) {
            dlg.Control("editSearch").value = srcTab.selected(0).name_stem;
        }
        else {
            dlg.Control("editSearch").value = DOpus.GetClip();
        }
    }
    
    if (srcTab.stats.selitems < 1) {
        dlg.Control("btnFile").enabled = false;
    }

    dlg.Control("listEngines").columns.AutoSize();

    while (true) {
        var msg = dlg.GetMsg();
       if (!msg.result) break;

       if (msg.event == "click" && dlg.Control("btnFile").focus == true) {
            if (srcTab.stats.selitems > 0) {
                dlg.Control("editSearch").value = srcTab.selected(0).name_stem;
            }
       }

       if (msg.event == "click" && dlg.Control("btnClip").focus == true) {
           if (DOpus.GetClipFormat() == "text") {
               dlg.Control("editSearch").value = DOpus.GetClip();
           }
       }

       if (msg.event == "dblclk" && dlg.Control("listEngines").focus == true) {

            if (dlg.Control("listEngines").value == 0) {
                if (dlg.Control("listEngines").GetItemAt(0).subitems(0) == "Yes") {
                    DOpus.Vars.Set("Searcher_Google") = "No";
                    dlg.Control("listEngines").GetItemAt(0).subitems(0) = "No";
                }
                else {
                    DOpus.Vars.Set("Searcher_Google") = "Yes";
                    dlg.Control("listEngines").GetItemAt(0).subitems(0) = "Yes";
                }
            }

            if (dlg.Control("listEngines").value == 1) {
                if (dlg.Control("listEngines").GetItemAt(1).subitems(0) == "Yes") {
                    DOpus.Vars.Set("Searcher_Google_Images") = "No";
                    dlg.Control("listEngines").GetItemAt(1).subitems(0) = "No";
                }
                else {
                    DOpus.Vars.Set("Searcher_Google_Images") = "Yes";
                    dlg.Control("listEngines").GetItemAt(1).subitems(0) = "Yes";
                }
            }

            if (dlg.Control("listEngines").value == 2) {
                if (dlg.Control("listEngines").GetItemAt(2).subitems(0) == "Yes") {
                    DOpus.Vars.Set("Searcher_Bing") = "No";
                    dlg.Control("listEngines").GetItemAt(2).subitems(0) = "No";
                }
                else {
                    DOpus.Vars.Set("Searcher_Bing") = "Yes";
                    dlg.Control("listEngines").GetItemAt(2).subitems(0) = "Yes";
                }
            }

            if (dlg.Control("listEngines").value == 3) {
                if (dlg.Control("listEngines").GetItemAt(3).subitems(0) == "Yes") {
                    DOpus.Vars.Set("Searcher_Bing_Images") = "No";
                    dlg.Control("listEngines").GetItemAt(3).subitems(0) = "No";
                }
                else {
                    DOpus.Vars.Set("Searcher_Bing_Images") = "Yes";
                    dlg.Control("listEngines").GetItemAt(3).subitems(0) = "Yes";
                }
            }

            if (dlg.Control("listEngines").value == 4) {
                if (dlg.Control("listEngines").GetItemAt(4).subitems(0) == "Yes") {
                    DOpus.Vars.Set("Searcher_Duck") = "No";
                    dlg.Control("listEngines").GetItemAt(4).subitems(0) = "No";
                }
                else {
                    DOpus.Vars.Set("Searcher_Duck") = "Yes";
                    dlg.Control("listEngines").GetItemAt(4).subitems(0) = "Yes";
                }
            }

            if (dlg.Control("listEngines").value == 5) {
                if (dlg.Control("listEngines").GetItemAt(5).subitems(0) == "Yes") {
                    DOpus.Vars.Set("Searcher_Duck_Images") = "No";
                    dlg.Control("listEngines").GetItemAt(5).subitems(0) = "No";
                }
                else {
                    DOpus.Vars.Set("Searcher_Duck_Images") = "Yes";
                    dlg.Control("listEngines").GetItemAt(5).subitems(0) = "Yes";
                }
            }

            if (dlg.Control("listEngines").value == 6) {
                if (dlg.Control("listEngines").GetItemAt(6).subitems(0) == "Yes") {
                    DOpus.Vars.Set("Searcher_Wikipedia") = "No";
                    dlg.Control("listEngines").GetItemAt(6).subitems(0) = "No";
                }
                else {
                    DOpus.Vars.Set("Searcher_Wikipedia") = "Yes";
                    dlg.Control("listEngines").GetItemAt(6).subitems(0) = "Yes";
                }
            }

            if (dlg.Control("listEngines").value == 7) {
                if (dlg.Control("listEngines").GetItemAt(7).subitems(0) == "Yes") {
                    DOpus.Vars.Set("Searcher_Opus") = "No";
                    dlg.Control("listEngines").GetItemAt(7).subitems(0) = "No";
                }
                else {
                    DOpus.Vars.Set("Searcher_Opus") = "Yes";
                    dlg.Control("listEngines").GetItemAt(7).subitems(0) = "Yes";
                }
            }

       }

       if (msg.event == "click" && dlg.Control("btnSearch").focus == true) {

            var strSearch = dlg.Control("editSearch").value;
            var strNewSearch = strSearch.replace(/\s/g, "+");
            var cmd = scriptCmdData.func.command;
            var intSearch = 0;

            if (dlg.Control("listEngines").GetItemAt(0).subitems(0) == "Yes") {
                //var strNewSearch = strSearch.replace(/\s/g, "+");
                intSearch = 1;
                cmd.AddLine("https://www.google.com/search?q=" + strNewSearch);
            }

            if (dlg.Control("listEngines").GetItemAt(1).subitems(0) == "Yes") {
                intSearch = 1;
                cmd.AddLine("https://www.google.com/search?tbm=isch&q=" + strNewSearch);
            }

            if (dlg.Control("listEngines").GetItemAt(2).subitems(0) == "Yes") {
                intSearch = 1;
                cmd.AddLine("https://www.bing.com/search?q=" + strNewSearch);
            }

            if (dlg.Control("listEngines").GetItemAt(3).subitems(0) == "Yes") {
                intSearch = 1;
                cmd.AddLine("https://www.bing.com/images/search?q=" + strNewSearch);
            }

            if (dlg.Control("listEngines").GetItemAt(4).subitems(0) == "Yes") {
                intSearch = 1;
                cmd.AddLine("https://duckduckgo.com/?q=" + strNewSearch);
            }

            if (dlg.Control("listEngines").GetItemAt(5).subitems(0) == "Yes") {
                intSearch = 1;
                cmd.AddLine("https://duckduckgo.com/?q=" + strNewSearch + "&ia=images&iax=images");
            }

            if (dlg.Control("listEngines").GetItemAt(6).subitems(0) == "Yes") {
                intSearch = 1;
                cmd.AddLine("https://en.wikipedia.org/wiki/" + strNewSearch);
            }

            if (dlg.Control("listEngines").GetItemAt(7).subitems(0) == "Yes") {
                intSearch = 1;
                cmd.AddLine("https://resource.dopus.com/search?q=" + strNewSearch);
            }

            if (intSearch == 1) {
                cmd.Run();
                cmd.Clear();
            }

       }
    }

    DOpus.Vars("Searcher_Google").persist = true;
    DOpus.Vars("Searcher_Google_Images").persist = true;
    DOpus.Vars("Searcher_Bing").persist = true;
    DOpus.Vars("Searcher_Bing_Images").persist = true;
    DOpus.Vars("Searcher_Duck").persist = true;
    DOpus.Vars("Searcher_Duck_Images").persist = true;
    DOpus.Vars("Searcher_Wikipedia").persist = true;
    DOpus.Vars("Searcher_Opus").persist = true;

    dlg.SavePosition("Steve_Searcher");

}

function OnAboutScript(aboutData){
    dlg = DOpus.Dlg;
    dlg.window = aboutData.window;
    dlg.title = scriptName + scriptVersion + " - Directory Opus";
    dlg.message = scriptName + " v" + scriptVersion + "\t\t\t" + scriptDate + "\n\n" + scriptDesc + "\n\n" + scriptCopyright;
    dlg.buttons = "Close";
    dlg.icon = "info";
    dlg.show;
}

==SCRIPT RESOURCES
<resources>
	<resource name="dlgSearch" type="dialog">
		<dialog fontsize="8" height="148" lang="english" resize="yes" title="Searcher - Directory Opus" width="165">
			<control halign="left" height="12" name="editSearch" resize="w" type="edit" width="157" x="4" y="4" />
			<control height="14" name="btnFile" title="&amp;Filename" type="button" width="50" x="4" y="20" />
			<control height="14" name="btnClip" title="&amp;Clipboard" type="button" width="50" x="57" y="20" />
			<control fullrow="yes" height="88" name="listEngines" noheader="yes" nosortheader="yes" resize="wh" type="listview" viewmode="details" width="157" x="4" y="38" />
			<control default="yes" height="14" name="btnSearch" resize="xy" title="Search..." type="button" width="50" x="57" y="130" />
			<control close="0" height="14" name="btnClose" resize="xy" title="C&amp;lose" type="button" width="50" x="110" y="130" />
		</dialog>
	</resource>
</resources>
