﻿// The OnInit function is called by Directory Opus to initialize the script add-in
function OnInit(initData) {
  // Provide basic information about the script by initializing the properties of the ScriptInitData object
  initData.name = "Column: Custom Ext. Sort";
  initData.desc = "Extension sorting in a custom order";
  initData.copyright = "2014 wowbagger";
  initData.min_version = "12"
  initData.version = "1.2";
  initData.default_enable = true;
  // Create a new ScriptColumn object and initialize it to add the column to Opus
  for(var i = 0; i < config.columns.length; ++i) {
    var cmd = initData.AddColumn();
    cmd.name = config.columns[i].name;
    cmd.method = "OnCustomSort";
    cmd.label = config.columns[i].name;
    cmd.autogroup = true;       
    cmd.justify = "left";
  }
}
var config = {
  columns: [{
    name: "ext", //Sample sort config 1
    sortOrder: [{
        extension:"",
	extensionout:"-none-",
		sortKey: "-905"
      }, {
        extension:"exe",		//exe
        extensionout:"exe",
		sortKey: "-100"
      }, {
        extension:"lnk",
        extensionout:"lnk",
		sortKey: "-101"
      }, {
        extension:"bat",
        extensionout:"bat",
		sortKey: "-102"
      }, {
        extension:"com",
        extensionout:"com",
		sortKey: "-103"
      }, {
        extension:"msi",
        extensionout:"msi",
		sortKey: "-104"
      }, {
        extension:"mp3",		//music
        extensionout:"mp3",
		sortKey: "-201"
      }, {
        extension:"wav",
        extensionout:"wav",
		sortKey: "-202"
      }, {
        extension:"m4a",
        extensionout:"m4a",
		sortKey: "-203"
      }, {
        extension:"wma",
        extensionout:"wma",
		sortKey: "-204"
      }, {
        extension:"flac",
        extensionout:"flac",
		sortKey: "-205"
      }, {
        extension:"ogg",
        extensionout:"ogg",
		sortKey: "-206"
      }, {
        extension:"aup",
        extensionout:"aup",
		sortKey: "-280"
      }, {
        extension:"ptx",
        extensionout:"ptx",
		sortKey: "-281"
      }, {
        extension:"mp4",		//movie
        extensionout:"mp4",
		sortKey: "-301"
      }, {
        extension:"avi",
        extensionout:"avi",
		sortKey: "-302"
      }, {
        extension:"mpg",
        extensionout:"mpg",
		sortKey: "-303"
      }, {
        extension:"mkv",
        extensionout:"mkv",
		sortKey: "-304"
      }, {
        extension:"ogv",
        extensionout:"ogv",
		sortKey: "-305"
      }, {
        extension:"vob",
        extensionout:"vob",
		sortKey: "-306"
      }, {
        extension:"wmv",
        extensionout:"wmv",
		sortKey: "-307"
      }, {
        extension:"flv",
        extensionout:"flv",
		sortKey: "-308"
      }, {
        extension:"divx",
        extensionout:"divx",
		sortKey: "-309"
      }, {
  	extension:"webm",
        extensionout:"webm",
		sortKey: "-310"
      }, {
  	extension:"ogm",
        extensionout:"ogm",
		sortKey: "-311"
      }, {
  	extension:"m3u8",
        extensionout:"m3u8",
		sortKey: "-318"
      }, {
        extension:"srt",
        extensionout:"srt",
		sortKey: "-390"
      }, {
        extension:"sub",
        extensionout:"sub",
		sortKey: "-390"
      }, {
        extension:"bmp",		//pic
        extensionout:"bmp",
		sortKey: "-401"
      }, {
        extension:"jpg",
        extensionout:"jpg",
		sortKey: "-402"
      }, {
        extension:"gif",
        extensionout:"gif",
		sortKey: "-403"
      }, {
        extension:"png",
        extensionout:"png",
		sortKey: "-404"
      }, {
        extension:"jpeg",
        extensionout:"jpeg",
		sortKey: "-405"
      }, {
        extension:"webp",
        extensionout:"webp",
		sortKey: "-406"
      }, {
        extension:"jfif",
        extensionout:"jfif",
		sortKey: "-407"
      },{
        extension:"zip",		//archive
        extensionout:"zip",
		sortKey: "-501"
      }, {
        extension:"7z",
        extensionout:"7z",
		sortKey: "-502"
      }, {
        extension:"rar",
        extensionout:"rar",
		sortKey: "-503"
      }, {
        extension:"reg",		//text
	extensionout:"reg",
		sortKey: "-600."
      }, {		  
        extension:"txt",
	extensionout:"txt",
		sortKey: "-601"
      }, {
        extension:"doc",
        extensionout:"doc",
		sortKey: "-602"
      }, {
        extension:"pdf",
        extensionout:"pdf",
		sortKey: "-603"
      }, {
        extension:"xml",
        extensionout:"xml",
		sortKey: "-604"
      }, {
        extension:"xls",
        extensionout:"xls",
		sortKey: "-605"
      },{
        extension:"xlsx",
        extensionout:"xlsx",
		sortKey: "-606"
      },{
        extension:"xlsm",
        extensionout:"xlsM",
		sortKey: "-607"
      },{
        extension:"csv",
        extensionout:"__csv",
		sortKey: "-608"
      },{
        extension:"docx",
        extensionout:"docx",
		sortKey: "-609"
      },{
        extension:"lua",
        extensionout:"lua",
		sortKey: "-610"
      
      },{
        extension:"nfo",
        extensionout:"nfo",
		sortKey: "-611"
      },{
        extension:"ini",
        extensionout:"ini",
		sortKey: "-612"
      },{
        extension:"html",
        extensionout:"html",
		sortKey: "-630"
      },{
        extension:"url",
        extensionout:"url",
		sortKey: "-631"
      },{
        extension:"java",
        extensionout:"java",
		sortKey: "-650"
      },{
        extension:"json",
        extensionout:"json",
		sortKey: "-651"
      },{
        extension:"log",
        extensionout:"log",
		sortKey: "-800"
      }]
    }],
  debug: false
}
// Implement the OnCustomSort column (this entry point is an OnScriptColumn event).
function OnCustomSort(scriptColData) {
    var columnConfig = GetConfig(scriptColData.col);
    if(!columnConfig) return;
    var ext = scriptColData.item.ext.replace(".","").toLowerCase();
    var sortOrder = GetSortOrder(columnConfig, ext);
    if (!sortOrder) { 
      scriptColData.value = config.debug ? "0:nomatch" : "? "+ext+"";                                   //scriptColData.value = config.debug ? "0:nomatch" : "?"+ext+"";
      scriptColData.sort = 0;
      return;
    }
    
    else if (scriptColData.item.is_dir)
    {
      scriptColData.value = "\\";
      scriptColData.sort = sortOrder.sortKey;            //this line was added so folders get sorted before files
    }

    else
    {
      //scriptColData.value = config.debug ? sortOrder.sortKey + ":" + sortOrder.extension + ":" + sortOrder.extensionout : ext;
      scriptColData.value = config.debug ? sortOrder.sortKey + ":" + sortOrder.extension + ":" + sortOrder.extensionout : sortOrder.extensionout;
      scriptColData.sort = sortOrder.sortKey;
    }
}
function GetSortOrder(columnConfig, extension)
{
  var match = null;
  for(var i = 0; i < columnConfig.sortOrder.length; ++i) {
    if(columnConfig.sortOrder[i].extension.toLowerCase() == extension) {
      match = columnConfig.sortOrder[i];
      break;
    }
  }
  return match;
}
function GetConfig(key)
{
  var match = null;
  for(var i = 0; i < config.columns.length; ++i) {
    if(config.columns[i].name == key) {
      match = config.columns[i];
      break;
    }
  }
 return match;
}